==> filemv0.342.0.1.zip: source/listview.cpp <==

#include "defextern.h"

#ifndef STRICT
    #define STRICT
#endif
#include <windows.h>
#include <iostream.h>
#include <fstream.h>
#include <wininet.h>
#include <windowsx.h>
#include <commctrl.h>
/*
#include "password.h"
*/
#include "resource.h"
#include "myfilemv.h"
#include "initial.h"
#include "listview.h"

int CALLBACK MyCompProc(LPARAM lp1, LPARAM lp2, LPARAM lp3)
{
    static LVFINDINFO lvf;
    static int nItem1, nItem2;
    static char buf1[MAX_PATH], buf2[MAX_PATH];
    SORTDATA *lpsd;

    lpsd = (SORTDATA *)lp3;

    lvf.flags = LVFI_PARAM;
    lvf.lParam = lp1;
    nItem1 = ListView_FindItem(lpsd->hwndList, -1, &lvf);

    lvf.lParam = lp2;
    nItem2 = ListView_FindItem(lpsd->hwndList, -1, &lvf);
    
    ListView_GetItemText(lpsd->hwndList,
        nItem1, lpsd->isortSubItem, buf1, sizeof(buf1));

    ListView_GetItemText(lpsd->hwndList,
        nItem2, lpsd->isortSubItem, buf2, sizeof(buf2));
    if (lpsd->isortSubItem != 1 && lpsd->isortSubItem != 3) {
        if (lpsd->iUPDOWN == UP) {
            return(stricmp(buf1, buf2));
        } else {
            return(stricmp(buf1, buf2) * -1);
        }
    } else {
        if (lpsd->iUPDOWN == UP) {
            if (atoi(buf1) > atoi(buf2))
                return 1;
            else if (atoi(buf1) == atoi(buf2))
                return 0;
            else
                return -1;
        } else {
            if (atoi(buf1) > atoi(buf2))
                return -1;
            else if (atoi(buf1) == atoi(buf2))
                return 0;
            else
                return 1;
        }

    }
}

void ListSelected(HWND hList, int i)
{
	ListView_SetItemState(hList,i,LVIS_SELECTED,LVIS_SELECTED);
}

==> filemv0.351.0.4.zip: source/listview.cpp <==

#include "defextern.h"

#ifndef STRICT
    #define STRICT
#endif
#include <windows.h>
#include <iostream.h>
#include <fstream.h>
#include <wininet.h>
#include <windowsx.h>
#include <commctrl.h>
#include "resource.h"
#include "myfilemv.h"
#include "initial.h"
#include "listview.h"

int CALLBACK MyCompProc(LPARAM lp1, LPARAM lp2, LPARAM lp3)
{
    static LVFINDINFO lvf;
    static int nItem1, nItem2;
    static char buf1[MAX_PATH], buf2[MAX_PATH];
    SORTDATA *lpsd;

    lpsd = (SORTDATA *)lp3;

    lvf.flags = LVFI_PARAM;
    lvf.lParam = lp1;
    nItem1 = ListView_FindItem(lpsd->hwndList, -1, &lvf);

    lvf.lParam = lp2;
    nItem2 = ListView_FindItem(lpsd->hwndList, -1, &lvf);
    
    ListView_GetItemText(lpsd->hwndList,
        nItem1, lpsd->isortSubItem, buf1, sizeof(buf1));

    ListView_GetItemText(lpsd->hwndList,
        nItem2, lpsd->isortSubItem, buf2, sizeof(buf2));
    if (lpsd->isortSubItem != 1 && lpsd->isortSubItem != 3) {
        if (lpsd->iUPDOWN == UP) {
            return(stricmp(buf1, buf2));
        } else {
            return(stricmp(buf1, buf2) * -1);
        }
    } else {
        if (lpsd->iUPDOWN == UP) {
            if (atoi(buf1) > atoi(buf2))
                return 1;
            else if (atoi(buf1) == atoi(buf2))
                return 0;
            else
                return -1;
        } else {
            if (atoi(buf1) > atoi(buf2))
                return -1;
            else if (atoi(buf1) == atoi(buf2))
                return 0;
            else
                return 1;
        }

    }
}

void ListSelected(HWND hList, int i, BOOL fl)
{
	if(fl) 
	{
		ListView_SetItemState( hList, i, LVIS_SELECTED, LVIS_SELECTED);
	}
	else 
	{
		ListView_SetItemState( hList, i, 0, LVIS_SELECTED);
	}
}

void ListNonSelected( HWND hList )
{
	int i =0;
	int max =ListView_GetItemCount( hList );
	while( i< max )
	{
		ListView_SetItemState( hList, i, 0, LVIS_SELECTED);
		i++;
	}
}
